@@ -10,8 +10,8 @@
 
 #include <AkonadiCore/CollectionFetchJob>
 #include <AkonadiCore/CollectionFetchScope>
-#include <QString>
 #include <QSet>
+#include <QString>
 
 #include <QDebug>
 
@@ -22,8 +22,7 @@ CollectionLoader::CollectionLoader(QObject *parent)
 
 void CollectionLoader::load()
 {
-    Akonadi::CollectionFetchJob *job = new Akonadi::CollectionFetchJob(Akonadi::Collection::root(),
-                                                                       Akonadi::CollectionFetchJob::Recursive);
+    Akonadi::CollectionFetchJob *job = new Akonadi::CollectionFetchJob(Akonadi::Collection::root(), Akonadi::CollectionFetchJob::Recursive);
 
     job->fetchScope().setContentMimeTypes(KCalendarCore::Incidence::mimeTypes());
     connect(job, &Akonadi::CollectionFetchJob::result, this, &CollectionLoader::onCollectionsLoaded);
@@ -40,19 +39,12 @@ void CollectionLoader::onCollectionsLoaded(KJob *job)
     if (job->error() == 0) {
         Akonadi::CollectionFetchJob *cfj = qobject_cast<Akonadi::CollectionFetchJob *>(job);
         Q_ASSERT(cfj);
-#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
-        QSet<QString> mimeTypeSet = KCalendarCore::Incidence::mimeTypes().toSet();
-#else
         const QStringList mimetypes = KCalendarCore::Incidence::mimeTypes();
         QSet<QString> mimeTypeSet = QSet<QString>(mimetypes.begin(), mimetypes.end());
-#endif
-        foreach (const Akonadi::Collection &collection, cfj->collections()) {
+        const auto collections = cfj->collections();
+        for (const Akonadi::Collection &collection : collections) {
             const QStringList contentMimeTypesLst = collection.contentMimeTypes();
-#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
-            QSet<QString> collectionMimeTypeSet = contentMimeTypesLst.toSet();
-#else
             QSet<QString> collectionMimeTypeSet = QSet<QString>(contentMimeTypesLst.begin(), contentMimeTypesLst.end());
-#endif
             if (!mimeTypeSet.intersect(collectionMimeTypeSet).isEmpty()) {
                 m_collections << collection;
             }
