@@ -4,27 +4,27 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
+#include "backuper.h"
 #include "calendarjanitor.h"
 #include "options.h"
-#include "backuper.h"
 
 #include "console-version.h"
 
 #include <KAboutData>
 #include <KLocalizedString>
 
-#include <QCoreApplication>
-#include <QCommandLineParser>
 #include <QCommandLineOption>
-#include <QTextStream>
+#include <QCommandLineParser>
+#include <QCoreApplication>
 #include <QString>
+#include <QTextStream>
 #include <qglobal.h>
 
 #ifdef Q_OS_UNIX
-#    include <sys/types.h>
-#    include <sys/stat.h>
-#    include <fcntl.h>
-#    include <unistd.h>
+#include <fcntl.h>
+#include <sys/stat.h>
+#include <sys/types.h>
+#include <unistd.h>
 #endif
 
 static const QString progName = QStringLiteral("calendarjanitor");
@@ -33,28 +33,30 @@ static const char progDisplay[] = I18N_NOOP("CalendarJanitor");
 static const QString progVersion = QStringLiteral(KDEPIM_VERSION);
 static const char progDesc[] = I18N_NOOP("A command line interface to report and fix errors in your calendar data");
 
-static void print(const QString &message)
+#ifndef COMPILE_WITH_UNITY_CMAKE_SUPPORT
+static void printOut(const QString &message)
 {
     QTextStream out(stdout);
     out << message << "\n";
 }
+#endif
 
 static void printCollectionsUsage()
 {
-    print(i18n("Error while parsing %1", QStringLiteral("--collections")));
-    print(i18n("Example usage: %1", QStringLiteral("--collections 90,23,40")));
+    printOut(i18n("Error while parsing %1", QStringLiteral("--collections")));
+    printOut(i18n("Example usage: %1", QStringLiteral("--collections 90,23,40")));
 }
 
 static void silenceStderr()
 {
 #ifdef Q_OS_UNIX
     if (qgetenv("KDE_CALENDARJANITOR_DEBUG") != "1") {
-        //krazy:cond=syscalls since UNIX-only code
+        // krazy:cond=syscalls since UNIX-only code
         // Disable stderr so we can actually read what's going on
         int fd = ::open("/dev/null", O_WRONLY);
         ::dup2(fd, 2);
         ::close(fd);
-        //krazy:endcond=syscalls
+        // krazy:endcond=syscalls
     }
 #endif
 }
@@ -74,7 +76,7 @@ int main(int argv, char *argc[])
     QCommandLineOption fixOpt(QStringLiteral("fix"), i18n("Fix broken incidences"));
     QCommandLineOption backupOpt(QStringLiteral("backup"), i18n("Backup your calendar"), QStringLiteral("output.ics"));
     QCommandLineOption stripOldAlarmsOpt(QStringLiteral("strip-old-alarms"), i18n("Delete alarms older than 365 days"));
-    parser.addOptions({ colsOpt, fixOpt, backupOpt, stripOldAlarmsOpt });
+    parser.addOptions({colsOpt, fixOpt, backupOpt, stripOldAlarmsOpt});
     aboutData.setupCommandLine(&parser);
 
     parser.process(app);
@@ -83,9 +85,9 @@ int main(int argv, char *argc[])
     Options janitorOptions;
     if (parser.isSet(colsOpt)) {
         QString option = parser.value(colsOpt);
-        QStringList collections = option.split(QLatin1Char(','));
+        const QStringList collections = option.split(QLatin1Char(','));
         QList<Akonadi::Collection::Id> ids;
-        foreach (const QString &collection, collections) {
+        for (const QString &collection : collections) {
             bool ok = false;
             int num = collection.toInt(&ok);
             if (ok) {
@@ -105,17 +107,17 @@ int main(int argv, char *argc[])
     }
 
     if (parser.isSet(fixOpt) && parser.isSet(backupOpt)) {
-        print(i18n("--fix is incompatible with --backup"));
+        printOut(i18n("--fix is incompatible with --backup"));
         return -1;
     }
 
     if (parser.isSet(stripOldAlarmsOpt) && parser.isSet(backupOpt)) {
-        print(i18n("--strip-old-alarms is incompatible with --backup"));
+        printOut(i18n("--strip-old-alarms is incompatible with --backup"));
         return -1;
     }
 
     if (parser.isSet(stripOldAlarmsOpt) && parser.isSet(fixOpt)) {
-        print(i18n("--strip-old-alarms is incompatible with --fix"));
+        printOut(i18n("--strip-old-alarms is incompatible with --fix"));
         return -1;
     }
 
@@ -126,29 +128,27 @@ int main(int argv, char *argc[])
     QString backupFile;
     if (parser.isSet(fixOpt)) {
         janitorOptions.setAction(Options::ActionScanAndFix);
-        print(i18n("Running in fix mode."));
+        printOut(i18n("Running in fix mode."));
     } else if (parser.isSet(backupOpt)) {
         backupFile = parser.value(backupOpt);
         if (backupFile.isEmpty()) {
-            print(i18n("Please specify a output file."));
+            printOut(i18n("Please specify a output file."));
             return -1;
         }
         janitorOptions.setAction(Options::ActionBackup);
     } else {
-        print(i18n("Running in scan only mode."));
+        printOut(i18n("Running in scan only mode."));
         janitorOptions.setAction(Options::ActionScan);
     }
 
     switch (janitorOptions.action()) {
-    case Options::ActionBackup:
-    {
+    case Options::ActionBackup: {
         Backuper *backuper = new Backuper();
         backuper->backup(backupFile, janitorOptions.collections());
         break;
     }
     case Options::ActionScan:
-    case Options::ActionScanAndFix:
-    {
+    case Options::ActionScanAndFix: {
         CalendarJanitor *janitor = new CalendarJanitor(janitorOptions);
         janitor->start();
         break;
