@@ -23,25 +23,25 @@
 #include "konsolekalendar_debug.h"
 #include <KLocalizedString>
 
-#include <KCalUtils/HtmlExport>
-#include <kcalutils/htmlexportsettings.h>
-#include <AkonadiCore/AgentManager>
 #include <AkonadiCore/AgentInstance>
 #include <AkonadiCore/AgentInstanceCreateJob>
-#include <AkonadiCore/CollectionFetchJob>
+#include <AkonadiCore/AgentManager>
 #include <AkonadiCore/Collection>
+#include <AkonadiCore/CollectionFetchJob>
 #include <AkonadiCore/CollectionFetchScope>
+#include <KCalUtils/HtmlExport>
+#include <kcalutils/htmlexportsettings.h>
 
 #include <QDBusInterface>
 #include <QDBusReply>
+#include <QEventLoop>
 #include <QFile>
 #include <QFileInfo>
 #include <QTextStream>
-#include <QEventLoop>
 
+#include <iostream>
 #include <stdio.h>
 #include <stdlib.h>
-#include <iostream>
 
 using namespace KCalendarCore;
 using namespace std;
@@ -65,12 +65,9 @@ bool KonsoleKalendar::importCalendar()
 
 bool KonsoleKalendar::printCalendarList()
 {
-    Akonadi::CollectionFetchJob *job = new Akonadi::CollectionFetchJob(Akonadi::Collection::root(),
-                                                                       Akonadi::CollectionFetchJob::Recursive);
-    const QStringList mimeTypes = QStringList() << QStringLiteral("text/calendar")
-                                          << KCalendarCore::Event::eventMimeType()
-                                          << KCalendarCore::Todo::todoMimeType()
-                                          << KCalendarCore::Journal::journalMimeType();
+    Akonadi::CollectionFetchJob *job = new Akonadi::CollectionFetchJob(Akonadi::Collection::root(), Akonadi::CollectionFetchJob::Recursive);
+    const QStringList mimeTypes = QStringList() << QStringLiteral("text/calendar") << KCalendarCore::Event::eventMimeType()
+                                                << KCalendarCore::Todo::todoMimeType() << KCalendarCore::Journal::journalMimeType();
     job->fetchScope().setContentMimeTypes(mimeTypes);
     QEventLoop loop;
     QObject::connect(job, &Akonadi::CollectionFetchJob::result, &loop, &QEventLoop::quit);
@@ -81,31 +78,22 @@ bool KonsoleKalendar::printCalendarList()
         return false;
     }
 
-    Akonadi::Collection::List collections = job->collections();
+    const Akonadi::Collection::List collections = job->collections();
 
     if (collections.isEmpty()) {
         cout << i18n("There are no calendars available.").toLocal8Bit().data() << endl;
     } else {
         cout << "--------------------------" << endl;
-#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
-        auto mimeTypeSet = mimeTypes.toSet();           // set changes by run method intersect
-#else
-        auto mimeTypeSet = QSet<QString>(mimeTypes.begin(), mimeTypes.end());           // set changes by run method intersect
-#endif
-        foreach (const Akonadi::Collection &collection, collections) {
+        auto mimeTypeSet = QSet<QString>(mimeTypes.begin(), mimeTypes.end()); // set changes by run method intersect
+        for (const Akonadi::Collection &collection : collections) {
             const QStringList contentMimeTypes = collection.contentMimeTypes();
-#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
-            auto collectionMimeTypeSet = contentMimeTypes.toSet();
-#else
             auto collectionMimeTypeSet = QSet<QString>(contentMimeTypes.begin(), contentMimeTypes.end());
-#endif
 
             if (!mimeTypeSet.intersect(collectionMimeTypeSet).isEmpty()) {
                 QString colId = QString::number(collection.id()).leftJustified(6, QLatin1Char(' '));
                 colId += QLatin1String("- ");
 
-                bool readOnly = !(collection.rights() & Akonadi::Collection::CanCreateItem
-                                  || collection.rights() & Akonadi::Collection::CanChangeItem
+                bool readOnly = !(collection.rights() & Akonadi::Collection::CanCreateItem || collection.rights() & Akonadi::Collection::CanChangeItem
                                   || collection.rights() & Akonadi::Collection::CanDeleteItem);
 
                 QString readOnlyString = readOnly ? i18n("(Read only)") + QLatin1Char(' ') : QString();
@@ -134,12 +122,12 @@ bool KonsoleKalendar::createAkonadiResource(const QString &icalFileUri)
     QDBusInterface iface(QStringLiteral("org.freedesktop.Akonadi.Resource.") + inst.identifier(), QStringLiteral("/Settings"));
     QDBusReply<void> reply = iface.call(QStringLiteral("setDisplayName"), QFileInfo(icalFileUri).baseName());
     if (!reply.isValid()) {
-        qCWarning(KONSOLEKALENDAR_LOG) << "Could not set setting 'name': "<<  reply.error().message();
+        qCWarning(KONSOLEKALENDAR_LOG) << "Could not set setting 'name': " << reply.error().message();
         return false;
     }
     reply = iface.call(QStringLiteral("setPath"), icalFileUri);
     if (!reply.isValid()) {
-        qCWarning(KONSOLEKALENDAR_LOG) << "Could not set setting 'path': "<<  reply.error().message();
+        qCWarning(KONSOLEKALENDAR_LOG) << "Could not set setting 'path': " << reply.error().message();
         return false;
     }
     inst.reconfigure();
@@ -153,16 +141,13 @@ bool KonsoleKalendar::createCalendar()
     const QString filename = m_variables->getCalendarFile();
 
     if (m_variables->isDryRun()) {
-        cout << i18n("Create Calendar <Dry Run>: %1", filename).toLocal8Bit().data()
-             << endl;
+        cout << i18n("Create Calendar <Dry Run>: %1", filename).toLocal8Bit().data() << endl;
     } else {
         qCDebug(KONSOLEKALENDAR_LOG) << "konsolekalendar.cpp::createCalendar() |"
-                                     << "Creating calendar file: "
-                                     << filename.toLocal8Bit().data();
+                                     << "Creating calendar file: " << filename.toLocal8Bit().data();
 
         if (m_variables->isVerbose()) {
-            cout << i18n("Create Calendar <Verbose>: %1", filename).toLocal8Bit().data()
-                 << endl;
+            cout << i18n("Create Calendar <Verbose>: %1", filename).toLocal8Bit().data() << endl;
         }
 
         status = createAkonadiResource(QStringLiteral("file://%1").arg(filename));
@@ -181,8 +166,7 @@ bool KonsoleKalendar::showInstance()
     Akonadi::CalendarBase::Ptr calendar = m_variables->getCalendar();
 
     if (m_variables->isDryRun()) {
-        cout << qPrintable(i18n("View Events <Dry Run>:"))
-             << endl;
+        cout << qPrintable(i18n("View Events <Dry Run>:")) << endl;
         printSpecs();
     } else {
         qCDebug(KONSOLEKALENDAR_LOG) << "konsolekalendar.cpp::showInstance() |"
@@ -193,8 +177,7 @@ bool KonsoleKalendar::showInstance()
             if (!f.open(QIODevice::WriteOnly)) {
                 status = false;
                 qCDebug(KONSOLEKALENDAR_LOG) << "konsolekalendar.cpp::showInstance() |"
-                                             << "unable to open export file"
-                                             << m_variables->getExportFile();
+                                             << "unable to open export file" << m_variables->getExportFile();
             }
         } else {
             f.open(stdout, QIODevice::WriteOnly);
@@ -205,35 +188,33 @@ bool KonsoleKalendar::showInstance()
                                          << "opened successful";
 
             if (m_variables->isVerbose()) {
-                cout << i18n("View Event <Verbose>:").toLocal8Bit().data()
-                     << endl;
+                cout << i18n("View Event <Verbose>:").toLocal8Bit().data() << endl;
                 printSpecs();
             }
 
             QTextStream ts(&f);
 
-            if (m_variables->getExportType() != ExportTypeHTML
-                && m_variables->getExportType() != ExportTypeMonthHTML) {
+            if (m_variables->getExportType() != ExportTypeHTML && m_variables->getExportType() != ExportTypeMonthHTML) {
                 if (m_variables->getAll()) {
                     qCDebug(KONSOLEKALENDAR_LOG) << "konsolekalendar.cpp::showInstance() |"
                                                  << "view all events sorted list";
 
-                    Event::List sortedList = calendar->events(EventSortStartDate);
+                    const Event::List sortedList = calendar->events(EventSortStartDate);
                     qCDebug(KONSOLEKALENDAR_LOG) << "Found" << sortedList.count() << "events";
                     if (!sortedList.isEmpty()) {
                         // The code that was here before the akonadi port was really slow with 200 events
                         // this is much faster:
-                        foreach (const KCalendarCore::Event::Ptr &event, sortedList) {
+                        for (const KCalendarCore::Event::Ptr &event : sortedList) {
                             status &= printEvent(&ts, event, event->dtStart().date());
                         }
                     }
                 } else if (m_variables->isUID()) {
                     qCDebug(KONSOLEKALENDAR_LOG) << "konsolekalendar.cpp::showInstance() |"
                                                  << "view events by uid list";
-                    //TODO: support a list of UIDs
+                    // TODO: support a list of UIDs
                     event = calendar->event(m_variables->getUID());
-                    //If this UID represents a recurring Event,
-                    //only the first day of the Event will be printed
+                    // If this UID represents a recurring Event,
+                    // only the first day of the Event will be printed
                     status = printEvent(&ts, event, event->dtStart().date());
                 } else if (m_variables->isNext()) {
                     qCDebug(KONSOLEKALENDAR_LOG) << "konsolekalendar.cpp::showInstance() |"
@@ -243,12 +224,8 @@ bool KonsoleKalendar::showInstance()
                     datetime = datetime.addDays(720);
 
                     QDate dt;
-                    for (dt = m_variables->getStartDateTime().date();
-                         dt <= datetime.date();
-                         dt = dt.addDays(1)) {
-                        Event::List events = calendar->events(dt, timeZone,
-                                                              EventSortStartDate,
-                                                              SortDirectionAscending);
+                    for (dt = m_variables->getStartDateTime().date(); dt <= datetime.date(); dt = dt.addDays(1)) {
+                        Event::List events = calendar->events(dt, timeZone, EventSortStartDate, SortDirectionAscending);
                         qCDebug(KONSOLEKALENDAR_LOG) << "2-Found" << events.count() << "events on date" << dt;
                         // finished here when we get the next event
                         if (!events.isEmpty()) {
@@ -263,12 +240,8 @@ bool KonsoleKalendar::showInstance()
                                                  << "view raw events within date range list";
 
                     QDate dt;
-                    for (dt = m_variables->getStartDateTime().date();
-                         dt <= m_variables->getEndDateTime().date() && status != false;
-                         dt = dt.addDays(1)) {
-                        Event::List events = calendar->events(dt, timeZone,
-                                                              EventSortStartDate,
-                                                              SortDirectionAscending);
+                    for (dt = m_variables->getStartDateTime().date(); dt <= m_variables->getEndDateTime().date() && status != false; dt = dt.addDays(1)) {
+                        Event::List events = calendar->events(dt, timeZone, EventSortStartDate, SortDirectionAscending);
                         qCDebug(KONSOLEKALENDAR_LOG) << "3-Found" << events.count() << "events on date: " << dt;
                         status = printEventList(&ts, &events, dt);
                     }
@@ -280,17 +253,14 @@ bool KonsoleKalendar::showInstance()
                                                  << "HTML view all events sorted list";
                     // sort the events for this date by start date
                     // in order to determine the date range.
-                    Event::List *events
-                        = new Event::List(calendar->rawEvents(EventSortStartDate,
-                                                              SortDirectionAscending));
+                    Event::List *events = new Event::List(calendar->rawEvents(EventSortStartDate, SortDirectionAscending));
                     firstdate = events->first()->dtStart().date();
                     lastdate = events->last()->dtStart().date();
                 } else if (m_variables->isUID()) {
                     // TODO
                     qCDebug(KONSOLEKALENDAR_LOG) << "konsolekalendar.cpp::showInstance() |"
                                                  << "HTML view events by uid list";
-                    cout << i18n("Sorry, export to HTML by UID is not supported yet").
-                        toLocal8Bit().data() << endl;
+                    cout << i18n("Sorry, export to HTML by UID is not supported yet").toLocal8Bit().data() << endl;
                     return false;
                 } else {
                     qCDebug(KONSOLEKALENDAR_LOG) << "konsolekalendar.cpp::showInstance() |"
@@ -301,10 +271,9 @@ bool KonsoleKalendar::showInstance()
 
                 KCalUtils::HTMLExportSettings htmlSettings(QStringLiteral("Konsolekalendar"));
 
-                //TODO: get progname and url from the values set in main
+                // TODO: get progname and url from the values set in main
                 htmlSettings.setCreditName(QStringLiteral("KonsoleKalendar"));
-                htmlSettings.setCreditURL(
-                    QStringLiteral("https://userbase.kde.org/KonsoleKalendar"));
+                htmlSettings.setCreditURL(QStringLiteral("https://userbase.kde.org/KonsoleKalendar"));
 
                 htmlSettings.setExcludePrivate(true);
                 htmlSettings.setExcludeConfidential(true);
@@ -316,27 +285,24 @@ bool KonsoleKalendar::showInstance()
                     htmlSettings.setMonthView(true);
                 } else {
                     if (firstdate == lastdate) {
-                        title = i18n("Events: %1",
-                                     firstdate.toString(Qt::TextDate));
+                        title = i18n("Events: %1", firstdate.toString(Qt::TextDate));
                     } else {
-                        title = i18n("Events: %1 - %2",
-                                     firstdate.toString(Qt::TextDate),
-                                     lastdate.toString(Qt::TextDate));
+                        title = i18n("Events: %1 - %2", firstdate.toString(Qt::TextDate), lastdate.toString(Qt::TextDate));
                     }
                     htmlSettings.setEventView(true);
                 }
                 htmlSettings.setEventTitle(title);
                 htmlSettings.setEventAttendees(true);
-// Not supporting Todos yet
-//         title = "To-Do List for " + firstdate.toString(Qt::TextDate);
-//         if ( firstdate != lastdate ) {
-//           title += " - " + lastdate.toString(Qt::TextDate);
-//         }
+                // Not supporting Todos yet
+                //         title = "To-Do List for " + firstdate.toString(Qt::TextDate);
+                //         if ( firstdate != lastdate ) {
+                //           title += " - " + lastdate.toString(Qt::TextDate);
+                //         }
                 htmlSettings.setTodoListTitle(title);
                 htmlSettings.setTodoView(false);
-//         htmlSettings.setTaskCategories( false );
-//         htmlSettings.setTaskAttendees( false );
-//         htmlSettings.setTaskDueDate( true );
+                //         htmlSettings.setTaskCategories( false );
+                //         htmlSettings.setTaskAttendees( false );
+                //         htmlSettings.setTaskDueDate( true );
 
 #if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
                 htmlSettings.setDateStart(QDateTime(firstdate));
@@ -346,7 +312,6 @@ bool KonsoleKalendar::showInstance()
                 htmlSettings.setDateEnd(QDateTime(lastdate.startOfDay()));
 #endif
 
-
                 KCalUtils::HtmlExport *exp = new KCalUtils::HtmlExport(calendar.data(), &htmlSettings);
                 status = exp->save(&ts);
                 delete exp;
@@ -366,9 +331,7 @@ bool KonsoleKalendar::printEventList(QTextStream *ts, Event::List *eventList, QD
         Event::Ptr singleEvent;
         Event::List::ConstIterator it;
 
-        for (it = eventList->constBegin();
-             it != eventList->constEnd() && status != false;
-             ++it) {
+        for (it = eventList->constBegin(); it != eventList->constEnd() && status != false; ++it) {
             singleEvent = *it;
 
             status = printEvent(ts, singleEvent, date);
@@ -400,14 +363,13 @@ bool KonsoleKalendar::printEvent(QTextStream *ts, const Event::Ptr &event, QDate
                 m_saveDate = dt;
             }
             status = exports.exportAsTxtShort(ts, event, dt, sameDay);
-        }
-            break;
+        } break;
 
         case ExportTypeHTML:
             // this is handled separately for now
             break;
 
-        default:// Default export-type is ExportTypeText
+        default: // Default export-type is ExportTypeText
             qCDebug(KONSOLEKALENDAR_LOG) << "konsolekalendar.cpp::printEvent() |"
                                          << "TEXT export";
             status = exports.exportAsTxt(ts, event, dt);
@@ -457,14 +419,10 @@ bool KonsoleKalendar::isEvent(const QDateTime &startdate, const QDateTime &endda
     bool found = false;
 
     const auto timeZone = m_variables->getCalendar()->timeZone();
-    Event::List eventList(m_variables->getCalendar()->
-                          rawEventsForDate(startdate.date(), timeZone,
-                                           EventSortStartDate,
-                                           SortDirectionAscending));
+    Event::List eventList(m_variables->getCalendar()->rawEventsForDate(startdate.date(), timeZone, EventSortStartDate, SortDirectionAscending));
     for (it = eventList.constBegin(); it != eventList.constEnd(); ++it) {
         event = *it;
-        if (event->dtEnd().toTimeZone(timeZone) == enddate
-            && event->summary() == summary) {
+        if (event->dtEnd().toTimeZone(timeZone) == enddate && event->summary() == summary) {
             found = true;
             break;
         }
@@ -474,28 +432,17 @@ bool KonsoleKalendar::isEvent(const QDateTime &startdate, const QDateTime &endda
 
 void KonsoleKalendar::printSpecs()
 {
-    cout << i18n("  What:  %1",
-                 m_variables->getSummary()).toLocal8Bit().data()
-         << endl;
+    cout << i18n("  What:  %1", m_variables->getSummary()).toLocal8Bit().data() << endl;
 
-    cout << i18n("  Begin: %1",
-                 m_variables->getStartDateTime().toString(Qt::TextDate)).toLocal8Bit().data()
-         << endl;
+    cout << i18n("  Begin: %1", m_variables->getStartDateTime().toString(Qt::TextDate)).toLocal8Bit().data() << endl;
 
-    cout << i18n("  End:   %1",
-                 m_variables->getEndDateTime().toString(Qt::TextDate)).toLocal8Bit().data()
-         << endl;
+    cout << i18n("  End:   %1", m_variables->getEndDateTime().toString(Qt::TextDate)).toLocal8Bit().data() << endl;
 
     if (m_variables->getFloating() == true) {
-        cout << i18n("  No Time Associated with Event").toLocal8Bit().data()
-             << endl;
+        cout << i18n("  No Time Associated with Event").toLocal8Bit().data() << endl;
     }
 
-    cout << i18n("  Desc:  %1",
-                 m_variables->getDescription()).toLocal8Bit().data()
-         << endl;
+    cout << i18n("  Desc:  %1", m_variables->getDescription()).toLocal8Bit().data() << endl;
 
-    cout << i18n("  Location:  %1",
-                 m_variables->getLocation()).toLocal8Bit().data()
-         << endl;
+    cout << i18n("  Location:  %1", m_variables->getLocation()).toLocal8Bit().data() << endl;
 }
